# Contributing

Bug reports, bug fixes, output improvements, best practice updates, and suggestions for new reports are welcomed.

## Style

Code is formatted with [black](https://github.com/psf/black). Types are checked with [mypy](https://mypy-lang.org).

Additionally, imports are grouped and sorted. [isort](https://github.com/PyCQA/isort) can help with that.

## Testing

Run tests with `python -m unittest tests/*.py`
